@@ -1,7 +1,6 @@
 """
 This is fully generated through the use of https://codebeautify.org/json-to-python-pojo-generator 
 """
-
 # This code parses date/times, so please
 #
 #     pip install python-dateutil
@@ -12,14 +11,16 @@ This is fully generated through the use of https://codebeautify.org/json-to-pyth
 #
 # and then, to convert JSON from a string, do
 #
-#     result = welcome4_from_dict(json.loads(json_string))
+#     result = welcome1_from_dict(json.loads(json_string))
 
-from typing import Any, List, Optional, TypeVar, Callable, Type, cast
+from typing import Any, List, TypeVar, Callable, Type, cast
+from enum import Enum
 from datetime import datetime
 import dateutil.parser
 
 
 T = TypeVar("T")
+EnumT = TypeVar("EnumT", bound=Enum)
 
 
 def from_str(x: Any) -> str:
@@ -45,25 +46,16 @@ def from_stringified_bool(x: str) -> bool:
     assert False
 
 
+def to_enum(c: Type[EnumT], x: Any) -> EnumT:
+    assert isinstance(x, c)
+    return x.value
+
+
 def from_none(x: Any) -> Any:
     assert x is None
     return x
 
 
-def from_union(fs, x):
-    for f in fs:
-        try:
-            return f(x)
-        except:
-            pass
-    assert False
-
-
-def is_type(t: Type[T], x: Any) -> T:
-    assert isinstance(x, t)
-    return x
-
-
 def from_datetime(x: Any) -> datetime:
     return dateutil.parser.parse(x)
 
@@ -145,32 +137,20 @@ class Groups:
 
 
 class AudioAdapter:
-    controller: str
     driver: str
-    enabled: bool
-    enabled_out: bool
 
-    def __init__(self, controller: str, driver: str, enabled: bool, enabled_out: bool) -> None:
-        self.controller = controller
+    def __init__(self, driver: str) -> None:
         self.driver = driver
-        self.enabled = enabled
-        self.enabled_out = enabled_out
 
     @staticmethod
     def from_dict(obj: Any) -> 'AudioAdapter':
         assert isinstance(obj, dict)
-        controller = from_str(obj.get("@controller"))
         driver = from_str(obj.get("@driver"))
-        enabled = from_stringified_bool(from_str(obj.get("@enabled")))
-        enabled_out = from_stringified_bool(from_str(obj.get("@enabledOut")))
-        return AudioAdapter(controller, driver, enabled, enabled_out)
+        return AudioAdapter(driver)
 
     def to_dict(self) -> dict:
         result: dict = {}
-        result["@controller"] = from_str(self.controller)
         result["@driver"] = from_str(self.driver)
-        result["@enabled"] = from_str(str(self.enabled).lower())
-        result["@enabledOut"] = from_str(str(self.enabled_out).lower())
         return result
 
 
@@ -192,76 +172,70 @@ class Ioapic:
         return result
 
 
-class TimeOffset:
-    value: str
-
-    def __init__(self, value: str) -> None:
-        self.value = value
-
-    @staticmethod
-    def from_dict(obj: Any) -> 'TimeOffset':
-        assert isinstance(obj, dict)
-        value = from_str(obj.get("@value"))
-        return TimeOffset(value)
-
-    def to_dict(self) -> dict:
-        result: dict = {}
-        result["@value"] = from_str(self.value)
-        return result
-
-
 class BIOS:
     ioapic: Ioapic
-    time_offset: TimeOffset
-    smbios_uuid_little_endian: Ioapic
 
-    def __init__(self, ioapic: Ioapic, time_offset: TimeOffset, smbios_uuid_little_endian: Ioapic) -> None:
+    def __init__(self, ioapic: Ioapic) -> None:
         self.ioapic = ioapic
-        self.time_offset = time_offset
-        self.smbios_uuid_little_endian = smbios_uuid_little_endian
 
     @staticmethod
     def from_dict(obj: Any) -> 'BIOS':
         assert isinstance(obj, dict)
         ioapic = Ioapic.from_dict(obj.get("IOAPIC"))
-        time_offset = TimeOffset.from_dict(obj.get("TimeOffset"))
-        smbios_uuid_little_endian = Ioapic.from_dict(obj.get("SmbiosUuidLittleEndian"))
-        return BIOS(ioapic, time_offset, smbios_uuid_little_endian)
+        return BIOS(ioapic)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["IOAPIC"] = to_class(Ioapic, self.ioapic)
-        result["TimeOffset"] = to_class(TimeOffset, self.time_offset)
-        result["SmbiosUuidLittleEndian"] = to_class(Ioapic, self.smbios_uuid_little_endian)
         return result
 
 
-class Clipboard:
-    mode: str
+class Order:
+    position: int
+    device: str
 
-    def __init__(self, mode: str) -> None:
-        self.mode = mode
+    def __init__(self, position: int, device: str) -> None:
+        self.position = position
+        self.device = device
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Clipboard':
+    def from_dict(obj: Any) -> 'Order':
         assert isinstance(obj, dict)
-        mode = from_str(obj.get("@mode"))
-        return Clipboard(mode)
+        position = int(from_str(obj.get("@position")))
+        device = from_str(obj.get("@device"))
+        return Order(position, device)
 
     def to_dict(self) -> dict:
         result: dict = {}
-        result["@mode"] = from_str(self.mode)
+        result["@position"] = from_str(str(self.position))
+        result["@device"] = from_str(self.device)
+        return result
+
+
+class Boot:
+    order: List[Order]
+
+    def __init__(self, order: List[Order]) -> None:
+        self.order = order
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'Boot':
+        assert isinstance(obj, dict)
+        order = from_list(Order.from_dict, obj.get("Order"))
+        return Boot(order)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["Order"] = from_list(lambda x: to_class(Order, x), self.order)
         return result
 
 
 class CPU:
-    count: int
     pae: Ioapic
     long_mode: Ioapic
     hardware_virt_ex_large_pages: Ioapic
 
-    def __init__(self, count: int, pae: Ioapic, long_mode: Ioapic, hardware_virt_ex_large_pages: Ioapic) -> None:
-        self.count = count
+    def __init__(self, pae: Ioapic, long_mode: Ioapic, hardware_virt_ex_large_pages: Ioapic) -> None:
         self.pae = pae
         self.long_mode = long_mode
         self.hardware_virt_ex_large_pages = hardware_virt_ex_large_pages
@@ -269,50 +243,33 @@ class CPU:
     @staticmethod
     def from_dict(obj: Any) -> 'CPU':
         assert isinstance(obj, dict)
-        count = int(from_str(obj.get("@count")))
         pae = Ioapic.from_dict(obj.get("PAE"))
         long_mode = Ioapic.from_dict(obj.get("LongMode"))
         hardware_virt_ex_large_pages = Ioapic.from_dict(obj.get("HardwareVirtExLargePages"))
-        return CPU(count, pae, long_mode, hardware_virt_ex_large_pages)
+        return CPU(pae, long_mode, hardware_virt_ex_large_pages)
 
     def to_dict(self) -> dict:
         result: dict = {}
-        result["@count"] = from_str(str(self.count))
         result["PAE"] = to_class(Ioapic, self.pae)
         result["LongMode"] = to_class(Ioapic, self.long_mode)
         result["HardwareVirtExLargePages"] = to_class(Ioapic, self.hardware_virt_ex_large_pages)
         return result
 
 
-class Display:
-    controller: str
-    vram_size: int
-
-    def __init__(self, controller: str, vram_size: int) -> None:
-        self.controller = controller
-        self.vram_size = vram_size
-
-    @staticmethod
-    def from_dict(obj: Any) -> 'Display':
-        assert isinstance(obj, dict)
-        controller = from_str(obj.get("@controller"))
-        vram_size = int(from_str(obj.get("@VRAMSize")))
-        return Display(controller, vram_size)
-
-    def to_dict(self) -> dict:
-        result: dict = {}
-        result["@controller"] = from_str(self.controller)
-        result["@VRAMSize"] = from_str(str(self.vram_size))
-        return result
+class Flags(Enum):
+    EMPTY = ""
+    RDONLYGUEST = "RDONLYGUEST"
+    TRANSIENT_RDONLYGUEST = "TRANSIENT, RDONLYGUEST"
+    TRANSIENT_TRANSRESET = "TRANSIENT, TRANSRESET"
 
 
 class GuestProperty:
     name: str
     value: str
     timestamp: str
-    flags: str
+    flags: Flags
 
-    def __init__(self, name: str, value: str, timestamp: str, flags: str) -> None:
+    def __init__(self, name: str, value: str, timestamp: str, flags: Flags) -> None:
         self.name = name
         self.value = value
         self.timestamp = timestamp
@@ -324,7 +281,7 @@ class GuestProperty:
         name = from_str(obj.get("@name"))
         value = from_str(obj.get("@value"))
         timestamp = from_str(obj.get("@timestamp"))
-        flags = from_str(obj.get("@flags"))
+        flags = Flags(obj.get("@flags"))
         return GuestProperty(name, value, timestamp, flags)
 
     def to_dict(self) -> dict:
@@ -332,7 +289,7 @@ class GuestProperty:
         result["@name"] = from_str(self.name)
         result["@value"] = from_str(self.value)
         result["@timestamp"] = from_str(self.timestamp)
-        result["@flags"] = from_str(self.flags)
+        result["@flags"] = to_enum(Flags, self.flags)
         return result
 
 
@@ -354,24 +311,6 @@ class GuestProperties:
         return result
 
 
-class HID:
-    pointing: str
-
-    def __init__(self, pointing: str) -> None:
-        self.pointing = pointing
-
-    @staticmethod
-    def from_dict(obj: Any) -> 'HID':
-        assert isinstance(obj, dict)
-        pointing = from_str(obj.get("@Pointing"))
-        return HID(pointing)
-
-    def to_dict(self) -> dict:
-        result: dict = {}
-        result["@Pointing"] = from_str(self.pointing)
-        return result
-
-
 class Memory:
     ram_size: int
 
@@ -438,15 +377,13 @@ class Adapter:
     slot: int
     enabled: bool
     mac_address: str
-    cable: bool
     type: str
     disabled_modes: DisabledModes
 
-    def __init__(self, slot: int, enabled: bool, mac_address: str, cable: bool, type: str, disabled_modes: DisabledModes) -> None:
+    def __init__(self, slot: int, enabled: bool, mac_address: str, type: str, disabled_modes: DisabledModes) -> None:
         self.slot = slot
         self.enabled = enabled
         self.mac_address = mac_address
-        self.cable = cable
         self.type = type
         self.disabled_modes = disabled_modes
 
@@ -456,17 +393,15 @@ class Adapter:
         slot = int(from_str(obj.get("@slot")))
         enabled = from_stringified_bool(from_str(obj.get("@enabled")))
         mac_address = from_str(obj.get("@MACAddress"))
-        cable = from_stringified_bool(from_str(obj.get("@cable")))
         type = from_str(obj.get("@type"))
         disabled_modes = DisabledModes.from_dict(obj.get("DisabledModes"))
-        return Adapter(slot, enabled, mac_address, cable, type, disabled_modes)
+        return Adapter(slot, enabled, mac_address, type, disabled_modes)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["@slot"] = from_str(str(self.slot))
         result["@enabled"] = from_str(str(self.enabled).lower())
         result["@MACAddress"] = from_str(self.mac_address)
-        result["@cable"] = from_str(str(self.cable).lower())
         result["@type"] = from_str(self.type)
         result["DisabledModes"] = to_class(DisabledModes, self.disabled_modes)
         return result
@@ -490,6 +425,46 @@ class Network:
         return result
 
 
+class VRDEProperties:
+    property: List[ExtraDataItem]
+
+    def __init__(self, property: List[ExtraDataItem]) -> None:
+        self.property = property
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'VRDEProperties':
+        assert isinstance(obj, dict)
+        property = from_list(ExtraDataItem.from_dict, obj.get("Property"))
+        return VRDEProperties(property)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["Property"] = from_list(lambda x: to_class(ExtraDataItem, x), self.property)
+        return result
+
+
+class RemoteDisplay:
+    enabled: bool
+    vrde_properties: VRDEProperties
+
+    def __init__(self, enabled: bool, vrde_properties: VRDEProperties) -> None:
+        self.enabled = enabled
+        self.vrde_properties = vrde_properties
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'RemoteDisplay':
+        assert isinstance(obj, dict)
+        enabled = from_stringified_bool(from_str(obj.get("@enabled")))
+        vrde_properties = VRDEProperties.from_dict(obj.get("VRDEProperties"))
+        return RemoteDisplay(enabled, vrde_properties)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["@enabled"] = from_str(str(self.enabled).lower())
+        result["VRDEProperties"] = to_class(VRDEProperties, self.vrde_properties)
+        return result
+
+
 class SharedFolder:
     name: str
     host_path: str
@@ -521,34 +496,34 @@ class SharedFolder:
 
 
 class SharedFolders:
-    shared_folder: List[SharedFolder]
+    shared_folder: SharedFolder
 
-    def __init__(self, shared_folder: List[SharedFolder]) -> None:
+    def __init__(self, shared_folder: SharedFolder) -> None:
         self.shared_folder = shared_folder
 
     @staticmethod
     def from_dict(obj: Any) -> 'SharedFolders':
         assert isinstance(obj, dict)
-        shared_folder = from_list(SharedFolder.from_dict, obj.get("SharedFolder"))
+        shared_folder = SharedFolder.from_dict(obj.get("SharedFolder"))
         return SharedFolders(shared_folder)
 
     def to_dict(self) -> dict:
         result: dict = {}
-        result["SharedFolder"] = from_list(lambda x: to_class(SharedFolder, x), self.shared_folder)
+        result["SharedFolder"] = to_class(SharedFolder, self.shared_folder)
         return result
 
 
-class AttachedDeviceImage:
+class Image:
     uuid: str
 
     def __init__(self, uuid: str) -> None:
         self.uuid = uuid
 
     @staticmethod
-    def from_dict(obj: Any) -> 'AttachedDeviceImage':
+    def from_dict(obj: Any) -> 'Image':
         assert isinstance(obj, dict)
         uuid = from_str(obj.get("@uuid"))
-        return AttachedDeviceImage(uuid)
+        return Image(uuid)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -561,16 +536,14 @@ class AttachedDevice:
     hotpluggable: bool
     port: int
     device: int
-    image: AttachedDeviceImage
-    passthrough: Optional[bool]
+    image: Image
 
-    def __init__(self, type: str, hotpluggable: bool, port: int, device: int, image: AttachedDeviceImage, passthrough: Optional[bool]) -> None:
+    def __init__(self, type: str, hotpluggable: bool, port: int, device: int, image: Image) -> None:
         self.type = type
         self.hotpluggable = hotpluggable
         self.port = port
         self.device = device
         self.image = image
-        self.passthrough = passthrough
 
     @staticmethod
     def from_dict(obj: Any) -> 'AttachedDevice':
@@ -579,9 +552,8 @@ class AttachedDevice:
         hotpluggable = from_stringified_bool(from_str(obj.get("@hotpluggable")))
         port = int(from_str(obj.get("@port")))
         device = int(from_str(obj.get("@device")))
-        image = AttachedDeviceImage.from_dict(obj.get("Image"))
-        passthrough = from_union([from_none, lambda x: from_stringified_bool(from_str(x))], obj.get("@passthrough"))
-        return AttachedDevice(type, hotpluggable, port, device, image, passthrough)
+        image = Image.from_dict(obj.get("Image"))
+        return AttachedDevice(type, hotpluggable, port, device, image)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -589,8 +561,7 @@ class AttachedDevice:
         result["@hotpluggable"] = from_str(str(self.hotpluggable).lower())
         result["@port"] = from_str(str(self.port))
         result["@device"] = from_str(str(self.device))
-        result["Image"] = to_class(AttachedDeviceImage, self.image)
-        result["@passthrough"] = from_union([lambda x: from_none((lambda x: is_type(type(None), x))(x)), lambda x: from_str((lambda x: str((lambda x: is_type(bool, x))(x)).lower())(x))], self.passthrough)
+        result["Image"] = to_class(Image, self.image)
         return result
 
 
@@ -600,22 +571,14 @@ class StorageController:
     port_count: int
     use_host_io_cache: bool
     bootable: bool
-    ide0_master_emulation_port: int
-    ide0_slave_emulation_port: int
-    ide1_master_emulation_port: int
-    ide1_slave_emulation_port: int
-    attached_device: List[AttachedDevice]
+    attached_device: AttachedDevice
 
-    def __init__(self, name: str, type: str, port_count: int, use_host_io_cache: bool, bootable: bool, ide0_master_emulation_port: int, ide0_slave_emulation_port: int, ide1_master_emulation_port: int, ide1_slave_emulation_port: int, attached_device: List[AttachedDevice]) -> None:
+    def __init__(self, name: str, type: str, port_count: int, use_host_io_cache: bool, bootable: bool, attached_device: AttachedDevice) -> None:
         self.name = name
         self.type = type
         self.port_count = port_count
         self.use_host_io_cache = use_host_io_cache
         self.bootable = bootable
-        self.ide0_master_emulation_port = ide0_master_emulation_port
-        self.ide0_slave_emulation_port = ide0_slave_emulation_port
-        self.ide1_master_emulation_port = ide1_master_emulation_port
-        self.ide1_slave_emulation_port = ide1_slave_emulation_port
         self.attached_device = attached_device
 
     @staticmethod
@@ -626,12 +589,8 @@ class StorageController:
         port_count = int(from_str(obj.get("@PortCount")))
         use_host_io_cache = from_stringified_bool(from_str(obj.get("@useHostIOCache")))
         bootable = from_stringified_bool(from_str(obj.get("@Bootable")))
-        ide0_master_emulation_port = int(from_str(obj.get("@IDE0MasterEmulationPort")))
-        ide0_slave_emulation_port = int(from_str(obj.get("@IDE0SlaveEmulationPort")))
-        ide1_master_emulation_port = int(from_str(obj.get("@IDE1MasterEmulationPort")))
-        ide1_slave_emulation_port = int(from_str(obj.get("@IDE1SlaveEmulationPort")))
-        attached_device = from_list(AttachedDevice.from_dict, obj.get("AttachedDevice"))
-        return StorageController(name, type, port_count, use_host_io_cache, bootable, ide0_master_emulation_port, ide0_slave_emulation_port, ide1_master_emulation_port, ide1_slave_emulation_port, attached_device)
+        attached_device = AttachedDevice.from_dict(obj.get("AttachedDevice"))
+        return StorageController(name, type, port_count, use_host_io_cache, bootable, attached_device)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -640,11 +599,7 @@ class StorageController:
         result["@PortCount"] = from_str(str(self.port_count))
         result["@useHostIOCache"] = from_str(str(self.use_host_io_cache).lower())
         result["@Bootable"] = from_str(str(self.bootable).lower())
-        result["@IDE0MasterEmulationPort"] = from_str(str(self.ide0_master_emulation_port))
-        result["@IDE0SlaveEmulationPort"] = from_str(str(self.ide0_slave_emulation_port))
-        result["@IDE1MasterEmulationPort"] = from_str(str(self.ide1_master_emulation_port))
-        result["@IDE1SlaveEmulationPort"] = from_str(str(self.ide1_slave_emulation_port))
-        result["AttachedDevice"] = from_list(lambda x: to_class(AttachedDevice, x), self.attached_device)
+        result["AttachedDevice"] = to_class(AttachedDevice, self.attached_device)
         return result
 
 
@@ -666,91 +621,29 @@ class StorageControllers:
         return result
 
 
-class Controller:
-    name: str
-    type: str
-
-    def __init__(self, name: str, type: str) -> None:
-        self.name = name
-        self.type = type
-
-    @staticmethod
-    def from_dict(obj: Any) -> 'Controller':
-        assert isinstance(obj, dict)
-        name = from_str(obj.get("@name"))
-        type = from_str(obj.get("@type"))
-        return Controller(name, type)
-
-    def to_dict(self) -> dict:
-        result: dict = {}
-        result["@name"] = from_str(self.name)
-        result["@type"] = from_str(self.type)
-        return result
-
-
-class Controllers:
-    controller: Controller
-
-    def __init__(self, controller: Controller) -> None:
-        self.controller = controller
-
-    @staticmethod
-    def from_dict(obj: Any) -> 'Controllers':
-        assert isinstance(obj, dict)
-        controller = Controller.from_dict(obj.get("Controller"))
-        return Controllers(controller)
-
-    def to_dict(self) -> dict:
-        result: dict = {}
-        result["Controller"] = to_class(Controller, self.controller)
-        return result
-
-
-class USB:
-    controllers: Controllers
-
-    def __init__(self, controllers: Controllers) -> None:
-        self.controllers = controllers
-
-    @staticmethod
-    def from_dict(obj: Any) -> 'USB':
-        assert isinstance(obj, dict)
-        controllers = Controllers.from_dict(obj.get("Controllers"))
-        return USB(controllers)
-
-    def to_dict(self) -> dict:
-        result: dict = {}
-        result["Controllers"] = to_class(Controllers, self.controllers)
-        return result
-
-
 class Hardware:
     cpu: CPU
     memory: Memory
-    hid: HID
-    display: Display
+    boot: Boot
+    remote_display: RemoteDisplay
     bios: BIOS
-    usb: USB
     network: Network
     audio_adapter: AudioAdapter
     shared_folders: SharedFolders
-    clipboard: Clipboard
-    drag_and_drop: Clipboard
+    clipboard: None
     guest_properties: GuestProperties
     storage_controllers: StorageControllers
 
-    def __init__(self, cpu: CPU, memory: Memory, hid: HID, display: Display, bios: BIOS, usb: USB, network: Network, audio_adapter: AudioAdapter, shared_folders: SharedFolders, clipboard: Clipboard, drag_and_drop: Clipboard, guest_properties: GuestProperties, storage_controllers: StorageControllers) -> None:
+    def __init__(self, cpu: CPU, memory: Memory, boot: Boot, remote_display: RemoteDisplay, bios: BIOS, network: Network, audio_adapter: AudioAdapter, shared_folders: SharedFolders, clipboard: None, guest_properties: GuestProperties, storage_controllers: StorageControllers) -> None:
         self.cpu = cpu
         self.memory = memory
-        self.hid = hid
-        self.display = display
+        self.boot = boot
+        self.remote_display = remote_display
         self.bios = bios
-        self.usb = usb
         self.network = network
         self.audio_adapter = audio_adapter
         self.shared_folders = shared_folders
         self.clipboard = clipboard
-        self.drag_and_drop = drag_and_drop
         self.guest_properties = guest_properties
         self.storage_controllers = storage_controllers
 
@@ -759,97 +652,82 @@ class Hardware:
         assert isinstance(obj, dict)
         cpu = CPU.from_dict(obj.get("CPU"))
         memory = Memory.from_dict(obj.get("Memory"))
-        hid = HID.from_dict(obj.get("HID"))
-        display = Display.from_dict(obj.get("Display"))
+        boot = Boot.from_dict(obj.get("Boot"))
+        remote_display = RemoteDisplay.from_dict(obj.get("RemoteDisplay"))
         bios = BIOS.from_dict(obj.get("BIOS"))
-        usb = USB.from_dict(obj.get("USB"))
         network = Network.from_dict(obj.get("Network"))
         audio_adapter = AudioAdapter.from_dict(obj.get("AudioAdapter"))
         shared_folders = SharedFolders.from_dict(obj.get("SharedFolders"))
-        clipboard = Clipboard.from_dict(obj.get("Clipboard"))
-        drag_and_drop = Clipboard.from_dict(obj.get("DragAndDrop"))
+        clipboard = from_none(obj.get("Clipboard"))
         guest_properties = GuestProperties.from_dict(obj.get("GuestProperties"))
         storage_controllers = StorageControllers.from_dict(obj.get("StorageControllers"))
-        return Hardware(cpu, memory, hid, display, bios, usb, network, audio_adapter, shared_folders, clipboard, drag_and_drop, guest_properties, storage_controllers)
+        return Hardware(cpu, memory, boot, remote_display, bios, network, audio_adapter, shared_folders, clipboard, guest_properties, storage_controllers)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["CPU"] = to_class(CPU, self.cpu)
         result["Memory"] = to_class(Memory, self.memory)
-        result["HID"] = to_class(HID, self.hid)
-        result["Display"] = to_class(Display, self.display)
+        result["Boot"] = to_class(Boot, self.boot)
+        result["RemoteDisplay"] = to_class(RemoteDisplay, self.remote_display)
         result["BIOS"] = to_class(BIOS, self.bios)
-        result["USB"] = to_class(USB, self.usb)
         result["Network"] = to_class(Network, self.network)
         result["AudioAdapter"] = to_class(AudioAdapter, self.audio_adapter)
         result["SharedFolders"] = to_class(SharedFolders, self.shared_folders)
-        result["Clipboard"] = to_class(Clipboard, self.clipboard)
-        result["DragAndDrop"] = to_class(Clipboard, self.drag_and_drop)
+        result["Clipboard"] = from_none(self.clipboard)
         result["GuestProperties"] = to_class(GuestProperties, self.guest_properties)
         result["StorageControllers"] = to_class(StorageControllers, self.storage_controllers)
         return result
 
 
-class DVDImagesImage:
+class HardDiskHardDisk:
     uuid: str
     location: str
+    format: str
 
-    def __init__(self, uuid: str, location: str) -> None:
+    def __init__(self, uuid: str, location: str, format: str) -> None:
         self.uuid = uuid
         self.location = location
+        self.format = format
 
     @staticmethod
-    def from_dict(obj: Any) -> 'DVDImagesImage':
+    def from_dict(obj: Any) -> 'HardDiskHardDisk':
         assert isinstance(obj, dict)
         uuid = from_str(obj.get("@uuid"))
         location = from_str(obj.get("@location"))
-        return DVDImagesImage(uuid, location)
+        format = from_str(obj.get("@format"))
+        return HardDiskHardDisk(uuid, location, format)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["@uuid"] = from_str(self.uuid)
         result["@location"] = from_str(self.location)
+        result["@format"] = from_str(self.format)
         return result
 
 
-class DVDImages:
-    image: DVDImagesImage
-
-    def __init__(self, image: DVDImagesImage) -> None:
-        self.image = image
-
-    @staticmethod
-    def from_dict(obj: Any) -> 'DVDImages':
-        assert isinstance(obj, dict)
-        image = DVDImagesImage.from_dict(obj.get("Image"))
-        return DVDImages(image)
-
-    def to_dict(self) -> dict:
-        result: dict = {}
-        result["Image"] = to_class(DVDImagesImage, self.image)
-        return result
-
-
-class HardDisk:
+class HardDisksHardDisk:
     uuid: str
     location: str
     format: str
     type: str
+    hard_disk: HardDiskHardDisk
 
-    def __init__(self, uuid: str, location: str, format: str, type: str) -> None:
+    def __init__(self, uuid: str, location: str, format: str, type: str, hard_disk: HardDiskHardDisk) -> None:
         self.uuid = uuid
         self.location = location
         self.format = format
         self.type = type
+        self.hard_disk = hard_disk
 
     @staticmethod
-    def from_dict(obj: Any) -> 'HardDisk':
+    def from_dict(obj: Any) -> 'HardDisksHardDisk':
         assert isinstance(obj, dict)
         uuid = from_str(obj.get("@uuid"))
         location = from_str(obj.get("@location"))
         format = from_str(obj.get("@format"))
         type = from_str(obj.get("@type"))
-        return HardDisk(uuid, location, format, type)
+        hard_disk = HardDiskHardDisk.from_dict(obj.get("HardDisk"))
+        return HardDisksHardDisk(uuid, location, format, type, hard_disk)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -857,46 +735,77 @@ class HardDisk:
         result["@location"] = from_str(self.location)
         result["@format"] = from_str(self.format)
         result["@type"] = from_str(self.type)
+        result["HardDisk"] = to_class(HardDiskHardDisk, self.hard_disk)
         return result
 
 
 class HardDisks:
-    hard_disk: HardDisk
+    hard_disk: HardDisksHardDisk
 
-    def __init__(self, hard_disk: HardDisk) -> None:
+    def __init__(self, hard_disk: HardDisksHardDisk) -> None:
         self.hard_disk = hard_disk
 
     @staticmethod
     def from_dict(obj: Any) -> 'HardDisks':
         assert isinstance(obj, dict)
-        hard_disk = HardDisk.from_dict(obj.get("HardDisk"))
+        hard_disk = HardDisksHardDisk.from_dict(obj.get("HardDisk"))
         return HardDisks(hard_disk)
 
     def to_dict(self) -> dict:
         result: dict = {}
-        result["HardDisk"] = to_class(HardDisk, self.hard_disk)
+        result["HardDisk"] = to_class(HardDisksHardDisk, self.hard_disk)
         return result
 
 
 class MediaRegistry:
     hard_disks: HardDisks
-    dvd_images: DVDImages
 
-    def __init__(self, hard_disks: HardDisks, dvd_images: DVDImages) -> None:
+    def __init__(self, hard_disks: HardDisks) -> None:
         self.hard_disks = hard_disks
-        self.dvd_images = dvd_images
 
     @staticmethod
     def from_dict(obj: Any) -> 'MediaRegistry':
         assert isinstance(obj, dict)
         hard_disks = HardDisks.from_dict(obj.get("HardDisks"))
-        dvd_images = DVDImages.from_dict(obj.get("DVDImages"))
-        return MediaRegistry(hard_disks, dvd_images)
+        return MediaRegistry(hard_disks)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["HardDisks"] = to_class(HardDisks, self.hard_disks)
-        result["DVDImages"] = to_class(DVDImages, self.dvd_images)
+        return result
+
+
+class Snapshot:
+    uuid: str
+    name: str
+    time_stamp: datetime
+    state_file: str
+    hardware: Hardware
+
+    def __init__(self, uuid: str, name: str, time_stamp: datetime, state_file: str, hardware: Hardware) -> None:
+        self.uuid = uuid
+        self.name = name
+        self.time_stamp = time_stamp
+        self.state_file = state_file
+        self.hardware = hardware
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'Snapshot':
+        assert isinstance(obj, dict)
+        uuid = from_str(obj.get("@uuid"))
+        name = from_str(obj.get("@name"))
+        time_stamp = from_datetime(obj.get("@timeStamp"))
+        state_file = from_str(obj.get("@stateFile"))
+        hardware = Hardware.from_dict(obj.get("Hardware"))
+        return Snapshot(uuid, name, time_stamp, state_file, hardware)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["@uuid"] = from_str(self.uuid)
+        result["@name"] = from_str(self.name)
+        result["@timeStamp"] = self.time_stamp.isoformat()
+        result["@stateFile"] = from_str(self.state_file)
+        result["Hardware"] = to_class(Hardware, self.hardware)
         return result
 
 
@@ -904,23 +813,29 @@ class Machine:
     uuid: str
     name: str
     os_type: str
+    state_file: str
+    current_snapshot: str
     snapshot_folder: str
+    current_state_modified: bool
     last_state_change: datetime
-    aborted: bool
     media_registry: MediaRegistry
     extra_data: ExtraData
+    snapshot: Snapshot
     hardware: Hardware
     groups: Groups
 
-    def __init__(self, uuid: str, name: str, os_type: str, snapshot_folder: str, last_state_change: datetime, aborted: bool, media_registry: MediaRegistry, extra_data: ExtraData, hardware: Hardware, groups: Groups) -> None:
+    def __init__(self, uuid: str, name: str, os_type: str, state_file: str, current_snapshot: str, snapshot_folder: str, current_state_modified: bool, last_state_change: datetime, media_registry: MediaRegistry, extra_data: ExtraData, snapshot: Snapshot, hardware: Hardware, groups: Groups) -> None:
         self.uuid = uuid
         self.name = name
         self.os_type = os_type
+        self.state_file = state_file
+        self.current_snapshot = current_snapshot
         self.snapshot_folder = snapshot_folder
+        self.current_state_modified = current_state_modified
         self.last_state_change = last_state_change
-        self.aborted = aborted
         self.media_registry = media_registry
         self.extra_data = extra_data
+        self.snapshot = snapshot
         self.hardware = hardware
         self.groups = groups
 
@@ -930,25 +845,31 @@ class Machine:
         uuid = from_str(obj.get("@uuid"))
         name = from_str(obj.get("@name"))
         os_type = from_str(obj.get("@OSType"))
+        state_file = from_str(obj.get("@stateFile"))
+        current_snapshot = from_str(obj.get("@currentSnapshot"))
         snapshot_folder = from_str(obj.get("@snapshotFolder"))
+        current_state_modified = from_stringified_bool(from_str(obj.get("@currentStateModified")))
         last_state_change = from_datetime(obj.get("@lastStateChange"))
-        aborted = from_stringified_bool(from_str(obj.get("@aborted")))
         media_registry = MediaRegistry.from_dict(obj.get("MediaRegistry"))
         extra_data = ExtraData.from_dict(obj.get("ExtraData"))
+        snapshot = Snapshot.from_dict(obj.get("Snapshot"))
         hardware = Hardware.from_dict(obj.get("Hardware"))
         groups = Groups.from_dict(obj.get("Groups"))
-        return Machine(uuid, name, os_type, snapshot_folder, last_state_change, aborted, media_registry, extra_data, hardware, groups)
+        return Machine(uuid, name, os_type, state_file, current_snapshot, snapshot_folder, current_state_modified, last_state_change, media_registry, extra_data, snapshot, hardware, groups)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["@uuid"] = from_str(self.uuid)
         result["@name"] = from_str(self.name)
         result["@OSType"] = from_str(self.os_type)
+        result["@stateFile"] = from_str(self.state_file)
+        result["@currentSnapshot"] = from_str(self.current_snapshot)
         result["@snapshotFolder"] = from_str(self.snapshot_folder)
+        result["@currentStateModified"] = from_str(str(self.current_state_modified).lower())
         result["@lastStateChange"] = self.last_state_change.isoformat()
-        result["@aborted"] = from_str(str(self.aborted).lower())
         result["MediaRegistry"] = to_class(MediaRegistry, self.media_registry)
         result["ExtraData"] = to_class(ExtraData, self.extra_data)
+        result["Snapshot"] = to_class(Snapshot, self.snapshot)
         result["Hardware"] = to_class(Hardware, self.hardware)
         result["Groups"] = to_class(Groups, self.groups)
         return result
@@ -980,17 +901,17 @@ class VirtualBox:
         return result
 
 
-class Welcome4:
+class Welcome1:
     virtual_box: VirtualBox
 
     def __init__(self, virtual_box: VirtualBox) -> None:
         self.virtual_box = virtual_box
 
     @staticmethod
-    def from_dict(obj: Any) -> 'Welcome4':
+    def from_dict(obj: Any) -> 'Welcome1':
         assert isinstance(obj, dict)
         virtual_box = VirtualBox.from_dict(obj.get("VirtualBox"))
-        return Welcome4(virtual_box)
+        return Welcome1(virtual_box)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -998,10 +919,10 @@ class Welcome4:
         return result
 
 
-def welcome4_from_dict(s: Any) -> Welcome4:
-    return Welcome4.from_dict(s)
+def welcome1_from_dict(s: Any) -> Welcome1:
+    return Welcome1.from_dict(s)
 
 
-def welcome4_to_dict(x: Welcome4) -> Any:
-    return to_class(Welcome4, x)
+def welcome1_to_dict(x: Welcome1) -> Any:
+    return to_class(Welcome1, x)
 
